@@ -1,8 +1,8 @@
 # --
 # Kernel/Config/Defaults.pm - Default Config file for OTRS kernel
-# Copyright (C) 2001-2003 Martin Edenhofer <martin+code@otrs.org>
+# Copyright (C) 2001-2004 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: Defaults.pm,v 1.68.2.6 2003/06/01 17:14:25 martin Exp $
+# $Id: Defaults.pm,v 1.110 2004/02/15 21:34:38 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see 
 # the enclosed file COPYING for license information (GPL). If you 
@@ -20,7 +20,7 @@ package Kernel::Config::Defaults;
 
 use strict;
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.68.2.6 $';
+$VERSION = '$Revision: 1.110 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
@@ -44,6 +44,9 @@ sub LoadDefaults {
     # set this to e. g. 'Call#', 'MyTicket#' or 'Ticket#'.)
     $Self->{TicketHook} = 'Ticket#';
 
+    # TicketDivider
+    $Self->{TicketDivider} = ':';
+
     # FQDN
     # (Full qualified domain name of your system.)
     $Self->{FQDN} = 'yourhost.example.com';
@@ -69,6 +72,7 @@ sub LoadDefaults {
 
 #    $Self->{'SendmailModule'} = 'Kernel::System::Email::SMTP';
 #    $Self->{'SendmailModule::Host'} = 'mail.example.com';
+#    $Self->{'SendmailModule::Port'} = '25';
 #    $Self->{'SendmailModule::AuthUser'} = '';
 #    $Self->{'SendmailModule::AuthPassword'} = '';
 
@@ -91,10 +95,9 @@ sub LoadDefaults {
     # (show all ro and rw queues - not just rw queues)
     $Self->{QueueViewAllPossibleTickets} = 0; 
 
-    # MoveInToAllQueues -> useful for ASP
-    # (Possible to move in all queue? Not only queue which
-    # the own groups) [1|0]
-    $Self->{MoveInToAllQueues} = 1;
+    # QueueListType
+    # (show queues in system as tree or as list) [tree|list]
+    $Self->{QueueListType} = 'tree';
 
     # MoveType
     # (Show form drop down of show new page of new queues) [form|link]
@@ -186,13 +189,29 @@ sub LoadDefaults {
 #    $Self->{'AuthModule::LDAP::SearchUserDN'} = '';
 #    $Self->{'AuthModule::LDAP::SearchUserPw'} = '';
 
+
+    # This is an example configuration for an apache ($ENV{REMOTE_USER})
+    # auth. backend. Use it if you want to have a singe login through
+    # apache http-basic-auth
+#   $Self->{'AuthModule'} = 'Kernel::System::Auth::HTTPBasicAuth';
+    # Note:
+    # If you use this module, you should use as fallback the following
+    # config settings if user isn't login through apache ($ENV{REMOTE_USER})
+#   $Self->{LoginURL} = 'http://host.example.com/not-authorised-for-otrs.html';
+#   $Self->{LogoutURL} = 'http://host.example.com/thanks-for-using-otrs.html';
+
+    # UserSyncLDAPMap 
+    # (map if agent should create/synced from LDAP to DB after login)
+    $Self->{UserSyncLDAPMap} = {
+        # DB -> LDAP
+        Firstname => 'givenName',
+        Lastname => 'sn',
+        Email => 'mail',
+    };
+
     # --------------------------------------------------- #
     # default agent settings                              #
     # --------------------------------------------------- #
-    # ViewableTickets
-    # (The default viewable tickets a page.)
-    $Self->{ViewableTickets} = 15;
-
     # ViewableTicketLines
     # (Max viewable ticket lines in the QueueView.)
     $Self->{ViewableTicketLines} = 18;
@@ -206,13 +225,6 @@ sub LoadDefaults {
     # (Max viewable ticket lines in the QueueZoom.)
     $Self->{ViewableTicketLinesZoom} = 6000;
 
-    # ViewableTicketStatusMaxSize
-    # (max size of ticket status view, state, priority, customer id, 
-    # ... in QueueView and ZoomView)
-    $Self->{ViewableTicketStatusQueueMaxSize} = 15;
-    $Self->{ViewableTicketStatusZoomMaxSize} = 15;
-    $Self->{ViewableTicketStatusMailboxMaxSize} = 14;
-
     # MaxLimit
     # (Max viewable tickets a page.)
     $Self->{MaxLimit} = 1200;
@@ -235,6 +247,16 @@ sub LoadDefaults {
     $Self->{HighlightAge2} = 2880;
     $Self->{HighlightColor2} = 'red';
 
+    # agent interface notification module to check the used charset
+    $Self->{'Frontend::NotifyModule'}->{'1-CharsetCheck'} = {
+        Module => 'Kernel::Output::HTML::NotificationCharsetCheck',
+    };
+    # agent interface notification module to check the admin user id
+    # (don't work with user id 1 notification)
+    $Self->{'Frontend::NotifyModule'}->{'2-UID-Check'} = {
+        Module => 'Kernel::Output::HTML::NotificationUIDCheck',
+    };
+
     # --------------------------------------------------- #
     # AgentStatusView (shows all open tickets)            #
     # --------------------------------------------------- #
@@ -249,7 +271,7 @@ sub LoadDefaults {
 
     # defaut of shown article a page
     # [default: 15]
-    $Self->{SearchPageShown} = 15;
+    $Self->{SearchPageShown} = 40;
 
     # viewable ticket lines by search util
     # [default: 10]
@@ -283,6 +305,12 @@ sub LoadDefaults {
     # param for LogModule Kernel::System::Log::File (required!)
     $Self->{'LogModule::LogFile'} = '/tmp/otrs.log'; 
 
+    # param if the date (yyyy-mm) should be added as suffix to 
+    # logfile [0|1]
+#    $Self->{'LogModule::LogFile::Date'} = 0;
+
+    # system log cache size for admin system log (default 4k)
+#    $Self->{LogSystemCacheSize} = 4*1024;
     # --------------------------------------------------- #
     # web stuff                                           #
     # --------------------------------------------------- #
@@ -305,11 +333,15 @@ sub LoadDefaults {
 
     # SpellChecker
     # (If ispell or aspell is available, then we will provide a spelling
-    # checker) 
+    # checker.) 
 #    $Self->{SpellChecker} = '';
     $Self->{SpellChecker} = '/usr/bin/ispell';
     $Self->{SpellCheckerDictDefault} = 'english';
 
+    # SpellCheckerIgnore
+    # (A list of ignored words.)
+    $Self->{SpellCheckerIgnore} = ['www', 'webmail', 'https', 'http', 'html'];
+
     # DemoSystem
     # (If this is true, no agent preferences, like language and theme, via agent 
     # frontend can be updated! Just for the current session. Alow no password can
@@ -382,13 +414,25 @@ sub LoadDefaults {
 #    $Self->{TicketStorageModule} = 'Kernel::System::Ticket::ArticleStorageFS';
  
     # UncountedUnlockTime
-    # (don't count this hours as unlock time)
+    # (don't count this hours as unlock time - weekdays: Mon,Tue,Wed,Thu,Fri,Sat,Sun;)
     $Self->{UncountedUnlockTime} = {
         Fri => [ 16,17,18,19,20,21,22,23 ],
         Sat => [ 0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23 ],
         Sun => [ 0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23 ],
         Mon => [ 0,1,2,3,4,5,6,7,8 ],
     };
+
+    # SendNoPendingNotificationTime 
+    # (send no pending notification this hours)
+    $Self->{SendNoPendingNotificationTime} = {
+        Mon => [ 0,1,2,3,4,5,6 ],
+        Tue => [ 0,1,2,3,4,5,6 ],
+        Wed => [ 0,1,2,3,4,5,6 ],
+        Thu => [ 0,1,2,3,4,5,6 ],
+        Fri => [ 0,1,2,3,4,5,6,21,22,23 ],
+        Sat => [ 0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23 ],
+        Sun => [ 0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23 ],
+    };
     # --------------------------------------------------- #
     # TicketNumberGenerator                               # 
     # --------------------------------------------------- #
@@ -421,15 +465,15 @@ sub LoadDefaults {
     # choose your backend TicketViewAccelerator module
 
     # RuntimeDB 
-    # (generate each queue view on the fly from ticket table
-    # you will not have performance trouble till ~ 50.000 tickets 
+    # (generate each queue view on the fly from ticket table you will not 
+    # have performance trouble till ~ 60.000 tickets (till 6.000 open tickets)
     # in your system)
     $Self->{TicketIndexModule} = 'Kernel::System::Ticket::IndexAccelerator::RuntimeDB';
 
     # StaticDB
-    # (the most powerfull module, it should be used over 80.000 
-    # tickets in a system - use a extra ticket_index table, works like a view -
-    # use bin/RebuildTicketIndex.pl for initial index update)
+    # (the most powerfull module, it should be used over 80.000 (more the 6.000 
+    # open tickets) tickets in a system - use a extra ticket_index table, works 
+    # like a view - use bin/RebuildTicketIndex.pl for initial index update)
 #    $Self->{TicketIndexModule} = 'Kernel::System::Ticket::IndexAccelerator::StaticDB';
 
     # --------------------------------------------------- #
@@ -439,8 +483,11 @@ sub LoadDefaults {
     # default valid
     $Self->{DefaultValid} = 'valid';
     # default charset
-    # (default frontend charset) [default: iso-8859-1]
+    # (default frontend charset - "utf-8" is a multi chatset for all possible 
+    # charsets - e. g. "iso-8859-1" is also possible for single charset) 
+    # [default: iso-8859-1] 
     $Self->{DefaultCharset} = 'iso-8859-1';
+#    $Self->{DefaultCharset} = 'utf-8';
     # default langauge
     # (the default frontend langauge) [default: en]
     $Self->{DefaultLanguage} = 'en';
@@ -451,24 +498,25 @@ sub LoadDefaults {
             en => 'English',
             de => 'Deutsch',
             nl => 'Nederlands',
-            fr => 'Franais',
+            fr => 'Fran&ccedil;ais',
             bg => 'Bulgarian',
             fi => 'Suomi',
             es => 'Espaniol',
-            pt_BR => 'Portugus Brasileiro',
+            pt_BR => 'Portugu&ecirc;s Brasileiro',
+            pt => 'Portugu&ecirc;s',
             it => 'Italiano',
             ru => 'Russian',
-#            cs => 'Czech', 
+            cz => 'Czech', 
+            pl => 'Polski',
+            nb_NO => 'Norsk bokm&aring;l',
 #            hu => 'Hungarian',
-#            pl => 'Polski',
 #            ro => 'Romanian',
 #            hr => 'Croatian',
 #            sk => 'Slovak', 
 #            sl => 'Slovenian',
-#            pt => 'Portuguese',
 #            da => 'Dansk',
 #            sv => 'Svenska',
-#            no => 'Norwegian',
+            nb_NO => 'Norsk bokm&aring;l',
     };
     # default theme
     # (the default html theme) [default: Standard]
@@ -492,6 +540,10 @@ sub LoadDefaults {
 #    $Self->{TimeUnits} = ' (minutes)';
 #    $Self->{TimeUnits} = ' (hours)';
     $Self->{TimeUnits} = ' (work units)';
+    # ShowAlwaysLongTime
+    # (show always time in long /days hours minutes/ or short 
+    # /days hours/ format)
+    $Self->{ShowAlwaysLongTime} = 0;
     # PendingDiffTime
     # (Time in sec. which "pending date" shows per default) [default: 24*60*60 -=> 1d]
     $Self->{PendingDiffTime} = 24*60*60;
@@ -502,6 +554,26 @@ sub LoadDefaults {
     # (compose message must be spell checked)
     $Self->{FrontendNeedSpellCheck} = 0;
 
+    # --------------------------------------------------- #
+    # TicketFreeText                                      #
+    # (define free text options for frontend)             #
+    # --------------------------------------------------- #
+#    $Self->{"TicketFreeKey1"} = {
+#        '' => '-',
+#        'Product' => 'Product',
+#    };
+#    $Self->{"TicketFreeText1"} = {
+#        '' => '-',
+#        'PC' => 'PC',
+#        'Notebook' => 'Notebook',
+#        'LCD' => 'LCD',
+#        'Phone' => 'Phone',
+#    };
+#    $Self->{"TicketFreeKey2"} = {
+#        '' => '-',
+#        'Support' => 'Support',
+#    };
+
     # --------------------------------------------------- #
     # defaults for add note                               #
     # --------------------------------------------------- #
@@ -711,7 +783,10 @@ $Data{"Signature"}
       'Resent-From',
       'Precedence',
       'Mailing-List',
+      'References',
+      'In-Reply-To',
       'X-Loop',
+      'X-Spam-Flag',
       'X-No-Loop',
       'X-OTRS-Loop',
       'X-OTRS-Info',
@@ -727,12 +802,61 @@ $Data{"Signature"}
       'X-OTRS-ArticleValue1',
       'X-OTRS-ArticleValue2',
       'X-OTRS-ArticleValue3',
+      'X-OTRS-SenderType',
+      'X-OTRS-ArticleType',
       'X-OTRS-TicketKey1',
       'X-OTRS-TicketKey2',
+      'X-OTRS-TicketKey3',
+      'X-OTRS-TicketKey4',
+      'X-OTRS-TicketKey5',
+      'X-OTRS-TicketKey6',
+      'X-OTRS-TicketKey7',
+      'X-OTRS-TicketKey8',
       'X-OTRS-TicketValue1',
       'X-OTRS-TicketValue2',
+      'X-OTRS-TicketValue3',
+      'X-OTRS-TicketValue4',
+      'X-OTRS-TicketValue5',
+      'X-OTRS-TicketValue6',
+      'X-OTRS-TicketValue7',
+      'X-OTRS-TicketValue8',
     ];
 
+    # --------------------------------------------------- #
+    # PostMaster Filter Modules                           #
+    # --------------------------------------------------- #
+    # PostMaster::PreFilterModule 
+    # (filtering and manipulaiting of incoming emails)
+
+    # Job Name: 1-Match 
+    # (block/ignore all spam email with From: noreply@)
+#    $Self->{'PostMaster::PreFilterModule'}->{'1-Match'} = {
+#        Module => 'Kernel::System::PostMaster::Filter::Match',
+#        Match => {
+#            From => 'noreply@',
+#        },
+#        Set => {
+#            'X-OTRS-Ignore' => 'yes',
+#        },
+#    };
+    # Job Name: 5-SpamAssassin 
+    # (SpamAssassin example setup, ignore spam emails)
+#    $Self->{'PostMaster::PreFilterModule'}->{'5-SpamAssassin'} = {
+#        Module => 'Kernel::System::PostMaster::Filter::CMD',
+#        CMD => '/usr/bin/spamassassin | grep -i "X-Spam-Status: yes"',
+#        Set => {
+#            'X-OTRS-Ignore' => 'yes',
+#        },
+#    };
+    # (SpamAssassin example setup, move it to spam queue)
+#    $Self->{'PostMaster::PreFilterModule'}->{'5-SpamAssassin'} = {
+#        Module => 'Kernel::System::PostMaster::Filter::CMD',
+#        CMD => '/usr/bin/spamassassin | grep -i "X-Spam-Status: yes"',
+#        Set => {
+#            'X-OTRS-Queue' => 'spam',
+#        },
+#    };
+
     # --------------------------------------------------- #
     # Auto Response                                       #
     # --------------------------------------------------- #
@@ -826,7 +950,7 @@ $Data{"Signature"}
             'NewTicketNotify', 'FollowUpNotify', 'LockTimeoutNotify', 'MoveNotify',
         ],
         Frontend => [
-            'Language', 'Charset', 'Theme', 'RefreshTime', 'QueueView', 
+            'Language', 'Theme', 'QueueViewShownTickets', 'QueueView', 'RefreshTime', 'CreateNextMask', 
         ],
         'Other Options' => [
             'Password', 'CustomQueue', 'SpellDict', 'FreeText', 'Comment',
@@ -948,14 +1072,6 @@ $Data{"Signature"}
         PrefKey => 'UserLanguage',
         Activ => 1,
     };
-    $Self->{PreferencesGroups}->{Charset} = {
-        Colum => 'Frontend', 
-        Label => 'Charset',
-        Desc => 'Select your frontend Charset.', 
-        Type => 'Generic',
-        PrefKey => 'UserCharset',
-        Activ => 1,
-    };
     $Self->{PreferencesGroups}->{Theme} = {
         Colum => 'Frontend', 
         Label => 'Theme',
@@ -977,7 +1093,35 @@ $Data{"Signature"}
         PrefKey => 'UserQueueView',
         Activ => 1,
     };
-
+    $Self->{PreferencesGroups}->{QueueViewShownTickets} = {
+        Colum => 'Frontend', 
+        Label => 'Shown Tickets',
+        Desc => 'Max. shown Tickets a page in QueueView.', 
+        Type => 'Generic',
+        Data => {
+            10 => 10,
+            15 => 15, 
+            20 => 20, 
+            25 => 25, 
+        },
+        DataSelected => 15,
+        PrefKey => 'UserQueueViewShowTickets',
+        Activ => 1,
+    };
+    $Self->{PreferencesGroups}->{CreateNextMask} = {
+        Colum => 'Frontend', 
+        Label => 'Screen after new ticket',
+        Desc => 'Select your screen after creating a new ticket.', 
+        Type => 'Generic',
+        Data => {
+            '' => 'CreateTicket',
+            AgentZoom => 'TicketZoom', 
+        },
+        DataSelected => '',
+#        DataSelected => 'AgentZoom',
+        PrefKey => 'UserCreateNextMask',
+        Activ => 1,
+    };
 
     # --------------------------------------------------- #
     #                                                     #
@@ -991,148 +1135,6 @@ $Data{"Signature"}
     # --
     $Self->{NotificationSenderName} = 'OTRS Notification Master';
     $Self->{NotificationSenderEmail} = 'otrs@<OTRS_CONFIG_FQDN>';
-    # --
-    # new ticket in queue
-    # --
-#    $Self->{NotificationAlwaysCcNewTicket} = 'Maybe a Mailinglist <list@example.com>';
-    $Self->{NotificationAlwaysCcNewTicket} = '';
-    $Self->{NotificationSubjectNewTicket} = 'New ticket notification! (<OTRS_CUSTOMER_SUBJECT[18]>)';
-    $Self->{NotificationBodyNewTicket} = "
-Hi,
-
-there is a new ticket in '<OTRS_QUEUE>'!
-
-<OTRS_CUSTOMER_FROM> wrote:
-<snip>
-<OTRS_CUSTOMER_EMAIL[16]>
-<snip>
-
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_ID>
-
-Your OTRS Notification Master
-
-";
-    # --
-    # new phone ticket in queue
-    # --
-    $Self->{NotificationAlwaysCcPhoneCallCustomer} = $Self->{NotificationAlwaysCcNewTicket};
-    $Self->{NotificationSubjectPhoneCallCustomer} = $Self->{NotificationSubjectNewTicket}; 
-    $Self->{NotificationBodyPhoneCallCustomer} = $Self->{NotificationBodyNewTicket};
-
-    # --
-    # ticket follow up from customer
-    # --
-#    $Self->{NotificationAlwaysCcFollowUp} = 'Maybe a Mailinglist <list@example.com>';
-    $Self->{NotificationAlwaysCcFollowUp} = '';
-    $Self->{NotificationSubjectFollowUp} = 'You got follow up! (<OTRS_CUSTOMER_SUBJECT[18]>)';
-    $Self->{NotificationBodyFollowUp} = "
-Hi <OTRS_OWNER_USERFIRSTNAME>,
-
-you got a follow up!
-
-<OTRS_CUSTOMER_FROM> wrote:
-<snip>
-<OTRS_CUSTOMER_EMAIL[16]>
-<snip>
-
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_ID>
-
-Your OTRS Notification Master
-
-";
-    # --
-    # ticket lock timeout by system
-    # --
-#    $Self->{NotificationAlwaysCcLockTimeout} = 'Maybe a Mailinglist <list@example.com>';
-    $Self->{NotificationAlwaysCcLockTimeout} = '';
-    $Self->{NotificationSubjectLockTimeout} = 'Lock Timeout! (<OTRS_CUSTOMER_SUBJECT[18]>)';
-    $Self->{NotificationBodyLockTimeout} = "
-Hi <OTRS_OWNER_USERFIRSTNAME>,
-
-unlocked (lock timeout) your locked ticket [<OTRS_TICKET_NUMBER>].
-
-<OTRS_CUSTOMER_FROM> wrote:
-<snip>
-<OTRS_CUSTOMER_EMAIL[8]>
-<snip>
-
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_ID>
-
-Your OTRS Notification Master
-
-";
-
-    # --
-    # mail to new owner by owner update
-    # --
-#    $Self->{NotificationAlwaysCcOwnerUpdate} = 'Maybe a Mailinglist <list@example.com>';
-    $Self->{NotificationAlwaysCcOwnerUpdate} = '';
-    $Self->{NotificationSubjectOwnerUpdate} = 'Ticket assigned to you! (<OTRS_CUSTOMER_SUBJECT[18]>)';
-    $Self->{NotificationBodyOwnerUpdate} = "
-Hi <OTRS_OWNER_USERFIRSTNAME>,
-
-a ticket [<OTRS_TICKET_NUMBER>] is assigned to you by '<OTRS_CURRENT_USERFIRSTNAME> <OTRS_CURRENT_USERLASTNAME>'.
-
-Comment: 
-<OTRS_COMMENT>
-
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_ID>
-
-Your OTRS Notification Master
-
-";
-    # --
-    # mail to owner by note add
-    # --
-#    $Self->{NotificationAlwaysCcNote} = '';
-    $Self->{NotificationSubjectAddNote} = 'New note! (<OTRS_CUSTOMER_SUBJECT[18]>)';
-    $Self->{NotificationBodyAddNote} = "
-Hi <OTRS_OWNER_USERFIRSTNAME>,
-
-'<OTRS_CURRENT_USERFIRSTNAME> <OTRS_CURRENT_USERLASTNAME>' added a new note to ticket [<OTRS_TICKET_NUMBER>].
-
-Note: 
-<OTRS_CUSTOMER_BODY>
-
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_ID>
-
-Your OTRS Notification Master
-
-";
-    # --
-    # mail to queue subscriber by move 
-    # --
-#    $Self->{NotificationAlwaysCcMove} = 'Maybe a Mailinglist <list@example.com>';
-    $Self->{NotificationAlwaysCcMove} = '';
-    $Self->{NotificationSubjectMove} = 'Moved ticket in "<OTRS_CUSTOMER_QUEUE>" queue! (<OTRS_CUSTOMER_SUBJECT[18]>)';
-    $Self->{NotificationBodyMove} = "
-Hi,
-
-'<OTRS_CURRENT_USERFIRSTNAME> <OTRS_CURRENT_USERLASTNAME>' moved a ticket [<OTRS_TICKET_NUMBER>] into '<OTRS_CUSTOMER_QUEUE>'.
-
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_ID>
-
-Your OTRS Notification Master
-
-";
-    # --
-    # ticket reminder notification
-    # --
-#    $Self->{NotificationAlwaysCcPendingReminder} = 'Maybe a Mailinglist <list@example.com>';
-    $Self->{NotificationAlwaysCcPendingReminder} = '';
-    $Self->{NotificationSubjectPendingReminder} = 'Ticket Reminder!';
-    $Self->{NotificationBodyPendingReminder} = "
-Hi <OTRS_OWNER_USERFIRSTNAME>,
-
-the ticket '<OTRS_TICKET_NUMBER>' has reached the reminder time!
-
-Please have a look at:
- 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_ID>
-
-Your OTRS Notification Master
-
-";
 
     # --
     # notification email for new password
@@ -1166,6 +1168,18 @@ Your OTRS Notification Master
     # (The customer panel db-uid.) [default: 1]
     $Self->{CustomerPanelUserID} = 1;
 
+    # CustomerGroupSupport (0 = compat. to OTRS 1.1 or lower)
+    # (if this is 1, the you need to set the group <-> customer user
+    # relations! http://host/otrs/index.pl?Action=AdminCustomerUserGroup
+    # otherway, each user is ro/rw in each group!)
+    $Self->{CustomerGroupSupport} = 0;
+ 
+    # CustomerGroupAlwaysGroups 
+    # (if CustomerGroupSupport is true and you don't want to manage
+    # each customer user for this groups, then put the groups
+    # for all customer user in there)
+    $Self->{CustomerGroupAlwaysGroups} = ['users', 'info'];
+
     # --------------------------------------------------- #
     # login and logout settings                           #
     # --------------------------------------------------- #
@@ -1222,21 +1236,22 @@ Your OTRS Notification Master
     $Self->{CustomerPanelNewArticleType} = 'webrequest';
     $Self->{CustomerPanelNewSenderType} = 'customer';
     # default history type
-    $Self->{CustomerPanelNewHistoryType} = 'NewTicket';
+    $Self->{CustomerPanelNewHistoryType} = 'WebRequestCustomer';
     $Self->{CustomerPanelNewHistoryComment} = 'Customer sent new ticket via web.';
 
     # CustomerPanelSelectionType 
     # (To: seection type. Queue => show all queues, SystemAddress => show all system 
     # addresses;) [Queue|SystemAddress]
-#    $Self->{CustomerPanelSelectionType} = 'Queue';
-    $Self->{CustomerPanelSelectionType} = 'SystemAddress';
+    $Self->{CustomerPanelSelectionType} = 'Queue';
+#    $Self->{CustomerPanelSelectionType} = 'SystemAddress';
 
     # CustomerPanelSelectionString
     # (String for To: selection.) 
     # use this for CustomerPanelSelectionType = Queue
 #    $Self->{CustomerPanelSelectionString} = 'Queue: <Queue> - <QueueComment>';
+    $Self->{CustomerPanelSelectionString} = '<Queue>';
     # use this for CustomerPanelSelectionType = SystemAddress
-    $Self->{CustomerPanelSelectionString} = '<Realname> <<Email>> - Queue: <Queue> - <QueueComment>';
+#    $Self->{CustomerPanelSelectionString} = '<Realname> <<Email>> - Queue: <Queue> - <QueueComment>';
 
     # CustomerPanelOwnSelection
     # (If this is in use, "just this selection is valid" for the CustomMessage.)
@@ -1354,12 +1369,22 @@ Your OTRS Notification Master
     # for non ldap posixGroups objectclass (full user dn)
 #    $Self->{'Customer::AuthModule::LDAP::UserAttr'} = 'DN';
 
-
     # The following is valid but would only be necessary if the
     # anonymous user do NOT have permission to read from the LDAP tree 
 #    $Self->{'Customer::AuthModule::LDAP::SearchUserDN'} = '';
 #    $Self->{'Customer::AuthModule::LDAP::SearchUserPw'} = '';
 
+
+    # This is an example configuration for an apache ($ENV{REMOTE_USER})
+    # auth. backend. Use it if you want to have a singe login through
+    # apache http-basic-auth
+#   $Self->{'Customer::AuthModule'} = 'Kernel::System::CustomerAuth::HTTPBasicAuth';
+    # Note:
+    # If you use this module, you should use as fallback the following
+    # config settings if user isn't login through apache ($ENV{REMOTE_USER})
+#    $Self->{CustomerPanelLoginURL} = 'http://host.example.com/not-authorised-for-otrs.html';
+#    $Self->{CustomerPanelLogoutURL} = 'http://host.example.com/thanks-for-using-otrs.html';
+
     # --------------------------------------------------- #
     #                                                     #
     #             Start of config options!!!              #
@@ -1368,22 +1393,25 @@ Your OTRS Notification Master
     # --------------------------------------------------- #
 
     # ShowCustomerInfo*
-    # (show customer user info on Phone, Zoom and Queue view)
-    $Self->{ShowCustomerInfoPhone} = 1;
+    # (show customer user info on Compose (Phone and Email), Zoom and Queue view)
+    $Self->{ShowCustomerInfoCompose} = 1;
     $Self->{ShowCustomerInfoZoom} = 1;
     $Self->{ShowCustomerInfoQueue} = 0;
 
     # ShowCustomerInfo*MaxSize
     # (max size (in characters) of customer info table)
-    $Self->{ShowCustomerInfoPhoneMaxSize} = 18;
-    $Self->{ShowCustomerInfoZoomMaxSize} = 18;
-    $Self->{ShowCustomerInfoQueueMaxSize} = 15;
+    $Self->{ShowCustomerInfoComposeMaxSize} = 22;
+    $Self->{ShowCustomerInfoZoomMaxSize} = 22;
+    $Self->{ShowCustomerInfoQueueMaxSize} = 18;
 
     # CustomerUser 
     # (customer user database backend and settings)
     $Self->{CustomerUser} = {
+        Name => 'Database Backend',
         Module => 'Kernel::System::CustomerUser::DB',
         Params => {
+            # if you want to use an external database, add the
+            # required settings
 #            DSN => 'DBI:odbc:yourdsn',
 #            DSN => 'DBI:mysql:database=customerdb;host=customerdbhost',
 #            User => '',
@@ -1395,7 +1423,7 @@ Your OTRS Notification Master
         # customer #
         CustomerID => 'customer_id',
         CustomerValid => 'valid_id',
-        CustomerUserListFields => ['login', 'first_name', 'last_name', 'email'],
+        CustomerUserListFields => ['first_name', 'last_name', 'email'],
 #        CustomerUserListFields => ['login', 'first_name', 'last_name', 'customer_id', 'email'],
         CustomerUserSearchFields => ['login', 'last_name', 'customer_id'],
         CustomerUserPostMasterSearchFields => ['email'],
@@ -1412,7 +1440,7 @@ Your OTRS Notification Master
             [ 'UserEmail', 'Email', 'email', 0, 1, 'var' ],
 #            [ 'UserEmail', 'Email', 'email', 1, 1, 'var', '$Env{"CGIHandle"}?Action=AgentCompose&ResponseID=1&TicketID=$Data{"TicketID"}&ArticleID=$Data{"ArticleID"}' ],
             [ 'UserCustomerID', 'CustomerID', 'customer_id', 0, 1, 'var' ],
-            [ 'UserComment', 'Comment', 'comment', 1, 0, 'var' ],
+            [ 'UserComment', 'Comment', 'comments', 1, 0, 'var' ],
             [ 'ValidID', 'Valid', 'valid_id', 0, 1, 'int' ],
         ],
     };
@@ -1420,6 +1448,7 @@ Your OTRS Notification Master
     # CustomerUser 
     # (customer user ldap backend and settings)
 #    $Self->{CustomerUser} = {
+#        Name => 'LDAP Backend',
 #        Module => 'Kernel::System::CustomerUser::LDAP',
 #        Params => {
 #            # ldap host
@@ -1437,7 +1466,7 @@ Your OTRS Notification Master
 #        CustomerKey => 'uid',
 #        # customer #
 #        CustomerID => 'mail',
-#        CustomerUserListFields => ['uid', 'cn', 'mail'],
+#        CustomerUserListFields => ['cn', 'mail'],
 #        CustomerUserSearchFields => ['uid', 'cn', 'mail'],
 #        CustomerUserPostMasterSearchFields => ['mail'],
 #        CustomerUserNameFields => ['givenname', 'sn'],
@@ -1479,7 +1508,7 @@ Your OTRS Notification Master
     # (Order of shown items)
     $Self->{CustomerPreferencesView} = {
         Frontend => [
-            'RefreshTime', 'Language', 'Charset', 'Theme', 
+            'ShownTickets', 'RefreshTime', 'Language', 'Theme', 
         ],
         'Other Options' => [
             'Password', 'ClosedTickets',
@@ -1504,7 +1533,21 @@ Your OTRS Notification Master
         PrefKey => 'UserShowClosedTickets',
         Activ => 1,
     };
-
+    $Self->{CustomerPreferencesGroups}->{ShownTickets} = {
+        Colum => 'Frontend',
+        Label => 'Shown Tickets',
+        Desc => 'Max. shown Tickets a page in Overview.',
+        Type => 'Generic',
+        Data => {
+            15 => 15,
+            20 => 20,
+            25 => 25,
+            30 => 30,
+        },
+        DataSelected => 25,
+        PrefKey => 'UserShowTickets',
+        Activ => 1,
+    };
     $Self->{CustomerPreferencesGroups}->{RefreshTime} = {
         Colum => 'Frontend', 
         Label => 'QueueView refresh time',
@@ -1530,14 +1573,6 @@ Your OTRS Notification Master
         PrefKey => 'UserLanguage',
         Activ => 1,
     };
-    $Self->{CustomerPreferencesGroups}->{Charset} = {
-        Colum => 'Frontend', 
-        Label => 'Charset',
-        Desc => 'Select your frontend Charset.', 
-        Type => 'Generic',
-        PrefKey => 'UserCharset',
-        Activ => 1,
-    };
     $Self->{CustomerPreferencesGroups}->{Theme} = {
         Colum => 'Frontend', 
         Label => 'Theme',
@@ -1578,40 +1613,38 @@ Your OTRS Notification Master
     $Self->{PhoneDefaultNewArticleType} = 'phone';
     $Self->{PhoneDefaultNewSenderType} = 'customer';
     # default note subject
-    $Self->{PhoneDefaultNewSubject} = '$Text{"Phone call at %s", "Time(DateFormatLong)"}';
+#    $Self->{PhoneDefaultNewSubject} = '$Text{"Phone call at %s", "Time(DateFormatLong)"}';
+    $Self->{PhoneDefaultNewSubject} = '';
     # default note text
-    $Self->{PhoneDefaultNewNoteText} = 'New ticket via call.';
+#    $Self->{PhoneDefaultNewNoteText} = 'New ticket via call.';
+    $Self->{PhoneDefaultNewNoteText} = '';
     # default next state [default: open]
     $Self->{PhoneDefaultNewNextState} = 'open';
-    # default lock (lock|unlock) [default: lock] 
-    $Self->{PhoneDefaultNewLock} = 'lock';
+    # default lock (lock|unlock) [default: unlock] 
+    $Self->{PhoneDefaultNewLock} = 'unlock';
     # default priority [default: 3 normal]
     $Self->{PhoneDefaultPriority} = '3 normal';
     # default history type
     $Self->{PhoneDefaultNewHistoryType} = 'PhoneCallCustomer';
     $Self->{PhoneDefaultNewHistoryComment} = 'Customer called us.';
 
-    # PhoneViewASP -> useful for ASP
-    # (Possible to create in all queue? Not only queue which
-    # the own groups) [0|1]
-    $Self->{PhoneViewASP} = 1;
-
     # PhoneViewOwnerSelection
     $Self->{PhoneViewOwnerSelection} = 1;
 
     # PhoneViewSelectionType 
     # (To: seection type. Queue => show all queues, SystemAddress => show all system 
     # addresses;) [Queue|SystemAddress]
-#    $Self->{PhoneViewSelectionType} = 'Queue';
-    $Self->{PhoneViewSelectionType} = 'SystemAddress';
+    $Self->{PhoneViewSelectionType} = 'Queue';
+#    $Self->{PhoneViewSelectionType} = 'SystemAddress';
 
     # PhoneViewSelectionString
     # (String for To: selection.) 
     # use this for PhoneViewSelectionType = Queue
 #   $Self->{PhoneViewSelectionString} = 'Queue: <Queue> - <QueueComment>';
-#   $Self->{PhoneViewSelectionString} = '<Queue>';
+   $Self->{PhoneViewSelectionString} = '<Queue>';
     # use this for PhoneViewSelectionType = SystemAddress
-    $Self->{PhoneViewSelectionString} = '<Realname> <<Email>> - Queue: <Queue> - <QueueComment>';
+#    $Self->{PhoneViewSelectionString} = '<Realname> <<Email>> - Queue: <Queue> - <QueueComment>';
+#    $Self->{PhoneViewSelectionString} = '<Realname> <<Email>> - Queue: <Queue>';
 
     # PhoneViewOwnSelection
     # (If this is in use, "just this selection is valid" for the PhoneView.)
@@ -1621,6 +1654,82 @@ Your OTRS Notification Master
 #        '2' => 'Second Queue!',
 #    };
 
+    # --------------------------------------------------- #
+    # agent compose email stuff
+    # --------------------------------------------------- #
+    # default lock (lock|unlock) [default: unlock] 
+    $Self->{EmailDefaultNewLock} = 'unlock';
+
+    # default priority [default: 3 normal]
+    $Self->{EmailDefaultPriority} = '3 normal';
+
+    # default article type
+    $Self->{EmailDefaultNewArticleType} = 'email-external';
+    # default sender type
+    $Self->{EmailDefaultNewSenderType} = 'agent';
+   
+    # history 
+    $Self->{EmailDefaultNewHistoryType} = 'EmailAgent';
+    $Self->{EmailDefaultNewHistoryComment} = 'Send email to customer.';
+
+    # default note text
+    $Self->{EmailDefaultNoteText} = '';
+
+    # next possible states after phone
+    $Self->{EmailDefaultNextStateType} = ['open', 'pending auto', 'pending reminder', 'closed'];
+    
+    # default next state
+    $Self->{EmailDefaultNewNextState} = 'open';
+
+
+    # --------------------------------------------------- #
+    # system permissions
+    # --------------------------------------------------- #
+    $Self->{'System::Permission'} = ['ro', 'move_into', 'create', 'owner', 'priority', 'rw'];
+#    $Self->{'System::Permission'} = ['ro', 'move_into', 'create', 'note', 'close', 'pending', 'owner', 'priority', 'customer', 'freetext', 'forward', 'bounce', 'move', 'rw'];
+    $Self->{'System::Customer::Permission'} = ['ro', 'rw'];
+
+    # --------------------------------------------------- #
+    # agent ticket permissions
+    # --------------------------------------------------- #
+    # Module Name: 1-OwnerCheck
+    # (if the current owner is already the user, grant access)
+    $Self->{'Ticket::Permission'}->{'1-OwnerCheck'} = {
+        Module => 'Kernel::System::Ticket::Permission::OwnerCheck',
+        Required => 0,
+    };
+    # Module Name: 2-GroupCheck
+    # (if the user is in this group with type ro|rw|..., grant access)
+    $Self->{'Ticket::Permission'}->{'2-GroupCheck'} = {
+        Module => 'Kernel::System::Ticket::Permission::GroupCheck',
+        Required => 0,
+    };
+
+    # --------------------------------------------------- #
+    # customer ticket permissions
+    # --------------------------------------------------- #
+    # Module Name: 1-CustomerIDGroupCheck
+    # (grant access, if customer id is the same and group is accessable)
+    $Self->{'CustomerTicket::Permission'}->{'1-CustomerIDCheck'} = {
+        Module => 'Kernel::System::Ticket::CustomerPermission::CustomerIDCheck',
+        Required => 1,
+    };
+    $Self->{'CustomerTicket::Permission'}->{'2-GroupCheck'} = {
+        Module => 'Kernel::System::Ticket::CustomerPermission::GroupCheck',
+        Required => 1,
+    };
+
+    # --------------------------------------------------- #
+    # FAQ settings
+    # --------------------------------------------------- #
+ 
+    $Self->{'FAQ::Field1'} = 'Symptom';
+    $Self->{'FAQ::Field2'} = 'Problem';
+    $Self->{'FAQ::Field3'} = 'Solution';
+    $Self->{'FAQ::Field4'} = 'field4';
+    $Self->{'FAQ::Field5'} = 'field5';
+    $Self->{'FAQ::Field6'} = 'Comment (internal)';
+
     # --------------------------------------------------- #
     # module group permissions
     # --------------------------------------------------- #
@@ -1628,8 +1737,8 @@ Your OTRS Notification Master
     $Self->{'Module::Permission'}->{'Admin'} = 'admin';
     $Self->{'Module::Permission'}->{'AdminAttachment'} = 'admin';
     $Self->{'Module::Permission'}->{'AdminAutoResponse'} = 'admin';
-    $Self->{'Module::Permission'}->{'AdminCharset'} = 'admin';
     $Self->{'Module::Permission'}->{'AdminCustomerUser'} = 'admin';
+    $Self->{'Module::Permission'}->{'AdminCustomerUserGroup'} = 'admin';
     $Self->{'Module::Permission'}->{'AdminEmail'} = 'admin';
     $Self->{'Module::Permission'}->{'AdminGroup'} = 'admin';
     $Self->{'Module::Permission'}->{'AdminLog'} = 'admin';
@@ -1648,7 +1757,14 @@ Your OTRS Notification Master
     $Self->{'Module::Permission'}->{'AdminUser'} = 'admin';
     $Self->{'Module::Permission'}->{'AdminUserGroup'} = 'admin';
 
-    $Self->{'Module::Permission'}->{'SystemStats'} = 'stats';
+    $Self->{'Module::Permission::Ro'}->{'FAQ'} = ['faq'];
+    $Self->{'Module::Permission::Ro'}->{'FAQHistory'} = ['faq'];
+    $Self->{'Module::Permission'}->{'FAQCategory'} = ['faq'];
+    $Self->{'Module::Permission'}->{'FAQLanguage'} = ['faq'];
+    $Self->{'Module::Permission'}->{'FAQArticle'} = ['faq'];
+
+    $Self->{'Module::Permission'}->{'SystemStats'} = ['admin', 'stats'];
+
     # --------------------------------------------------- #
 }
 # --
