@@ -1,8 +1,8 @@
 # --
 # Kernel/Language/de.pm - provides de language translation
-# Copyright (C) 2002-2003 Martin Edenhofer <martin at otrs.org>
+# Copyright (C) 2002-2004 Martin Edenhofer <martin at otrs.org>
 # --
-# $Id: de.pm,v 1.25 2003/04/22 11:53:16 robert Exp $
+# $Id: de.pm,v 1.40 2004/02/16 02:05:59 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -13,7 +13,7 @@ package Kernel::Language::de;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.25 $';
+$VERSION = '$Revision: 1.40 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
@@ -23,28 +23,32 @@ sub Data {
     my %Hash = ();
 
     # $$START$$
-    # Last translation Sun Apr 13 00:56:54 2003 by 
+    # Last translation Tue Feb 10 01:02:02 2004 by 
 
     # possible charsets
     $Self->{Charset} = ['iso-8859-1', 'iso-8859-15', ];
     # date formats (%A=WeekDay;%B=LongMonth;%T=Time;%D=Day;%M=Month;%Y=Jear;)
     $Self->{DateFormat} = '%D.%M.%Y %T';
     $Self->{DateFormatLong} = '%A %D %B %T %Y';
-    $Self->{DateInputFormat} = '%D.%M.%Y - %T';
+    $Self->{DateInputFormat} = '%D.%M.%Y';
+    $Self->{DateInputFormatLong} = '%D.%M.%Y - %T';
 
     %Hash = (
     # Template: AAABase
       ' 2 minutes' => ' 2 Minuten',
       ' 5 minutes' => ' 5 Minuten',
       ' 7 minutes' => ' 7 Minuten',
+      '(Click here to add)' => '(Hier klicken um hinzuzufgen)',
       '10 minutes' => '10 Minuten',
       '15 minutes' => '15 Minuten',
       'AddLink' => 'Link hinzufgen',
-      'AdminArea' => 'Admin-Oberflche',
+      'Admin-Area' => 'Admin-Bereich',
       'agent' => 'Agent',
+      'Agent-Area' => 'Agent-Bereich',
       'all' => 'alle',
       'All' => 'Alle',
       'Attention' => 'Achtung',
+      'before' => 'vor',
       'Bug Report' => 'Fehler berichten',
       'Cancel' => 'Abbrechen',
       'change' => 'ndern',
@@ -56,11 +60,13 @@ sub Data {
       'customer' => 'Kunde',
       'Customer Info' => 'Kunden-Info',
       'day' => 'Tag',
+      'day(s)' => 'Tag(e)',
       'days' => 'Tage',
       'description' => 'Beschreibung',
       'Description' => 'Beschreibung',
       'Dispatching by email To: field.' => 'Verteilung nach To: Feld.',
       'Dispatching by selected Queue.' => 'Verteilung nach ausgewhlter Queue.',
+      'Don\'t show closed Tickets' => 'Geschlossene Tickets nicht zeigen',
       'Don\'t work with UserID 1 (System account)! Create new users!' => 'Bitte nicht mit UserID 1 (System Account) arbeiten! Erstelle neue Benutzer!',
       'Done' => 'Fertig',
       'end' => 'runter',
@@ -68,6 +74,7 @@ sub Data {
       'Example' => 'Beispiel',
       'Examples' => 'Beispiele',
       'Facility' => 'Einrichtung',
+      'FAQ-Area' => 'FAQ-Bereich',
       'Feature not active!' => 'Funktion nicht aktiviert!',
       'go' => 'Start',
       'go!' => 'Start!',
@@ -81,6 +88,7 @@ sub Data {
       'Invalid SessionID!' => 'Ungltige SessionID!',
       'Language' => 'Sprache',
       'Languages' => 'Sprachen',
+      'last' => 'letzten',
       'Line' => 'Zeile',
       'Lite' => 'Einfach',
       'Login failed! Your username or password was entered incorrectly.' => 'Anmeldung fehlgeschlagen! Benutzername oder Passwort falsch.',
@@ -90,7 +98,9 @@ sub Data {
       'minutes' => 'Minuten',
       'Module' => 'Modul',
       'Modulefile' => 'Moduldatei',
+      'month(s)' => 'Monat(e)',
       'Name' => 'Name',
+      'New Article' => 'Neuer Artikel',
       'New message' => 'Neue Nachricht',
       'New message!' => 'Neue Nachricht!',
       'No' => 'Nein',
@@ -100,6 +110,7 @@ sub Data {
       'none' => 'keine',
       'none - answered' => 'keine - beantwortet',
       'none!' => 'keine Angabe!',
+      'Normal' => '',
       'Off' => 'Aus',
       'off' => 'aus',
       'On' => 'Ein',
@@ -109,13 +120,16 @@ sub Data {
       'Please answer this ticket(s) to get back to the normal queue view!' => 'Bitte beantworten Sie dieses Ticket, um in die normale Queue-Ansicht zurck zu kommen!',
       'Please contact your admin' => 'Bitte kontaktieren Sie Ihren Administrator',
       'please do not edit!' => 'Bitte nicht ndern!',
+      'Please go away!' => 'Bitte zurck gehen!',
       'possible' => 'mglich',
+      'Preview' => 'Vorschau',
       'QueueView' => 'Queue-Ansicht',
       'reject' => 'ablehnen',
       'replace with' => 'ersetzen mit',
       'Reset' => 'Rcksetzen',
       'Salutation' => 'Anrede',
       'Session has timed out. Please log in again.' => 'Session Zeitberschreitung. Bitte neu anmelden.',
+      'Show closed Tickets' => 'Geschlossene Tickets anzeigen',
       'Signature' => 'Signatur',
       'Sorry' => 'Bedauere',
       'Stats' => 'Statistik',
@@ -129,16 +143,20 @@ sub Data {
       'Theme' => 'Schema',
       'There is no account with that login name.' => 'Es existiert kein Benutzerkonto mit diesem Namen.',
       'Timeover' => 'Zeitberschreitung',
+      'To: (%s) replaced with database email!' => 'An: (%s) ersetzt mit Datenbank eMail',
       'top' => 'hoch',
       'update' => 'Aktualisieren',
+      'Update' => 'Aktualisieren',
       'update!' => 'Aktualisieren!',
       'User' => 'Benutzer',
       'Username' => 'Benutzername',
       'Valid' => 'Gltig',
       'Warning' => 'Warnung',
+      'week(s)' => 'Woche(n)',
       'Welcome to OTRS' => 'Willkommen zu OTRS',
       'Word' => 'Wort',
       'wrote' => 'schrieb',
+      'year(s)' => 'Jahr(e)',
       'yes' => 'ja',
       'Yes' => 'Ja',
       'You got new message!' => 'Sie haben eine neue Nachricht bekommen!',
@@ -160,22 +178,27 @@ sub Data {
       'Sep' => '',
 
     # Template: AAAPreferences
-      'Closed Tickets' => 'geschlossene Tickets',
+      'Closed Tickets' => 'Geschlossene Tickets',
       'Custom Queue' => 'Bevorzugte Queue',
       'Follow up notification' => 'Mitteilung bei Nachfragen',
       'Frontend' => 'Oberflche',
       'Mail Management' => '',
+      'Max. shown Tickets a page in Overview.' => 'Max. gezeigte Tickets pro Seite in der bersicht.',
+      'Max. shown Tickets a page in QueueView.' => 'Maximale Anzahl angezeigter Tickets in der Queue-Ansicht',
       'Move notification' => 'Mitteilung bei Queue-Wechsel',
       'New ticket notification' => 'Mitteilung bei neuem Ticket',
       'Other Options' => 'Andere Optionen',
+      'PhoneView' => 'Telefon-Ansicht',
       'Preferences updated successfully!' => 'Benutzereinstellungen erfolgreich aktualisiert!',
       'QueueView refresh time' => 'Queue-Ansicht Aktualisierungszeit',
+      'Screen after new ticket' => 'Fenster nach neuem Ticket',
       'Select your default spelling dictionary.' => 'Standard Rechtschreib-Wrterbuch auswhlen.',
       'Select your frontend Charset.' => 'Zeichensatz fr Darstellung auswhlen.',
       'Select your frontend language.' => 'Oberflchen-Sprache auswhlen.',
       'Select your frontend QueueView.' => 'Queue-Ansicht auswhlen.',
       'Select your frontend Theme.' => 'Anzeigeschema auswhlen.',
       'Select your QueueView refresh time.' => 'Queue-Ansicht Aktualisierungszeit auswhlen.',
+      'Select your screen after creating a new ticket.' => 'Whlen Sie das Fenster nach der Erstellung eines neuen Tickets.',
       'Send me a notification if a customer sends a follow up and I\'m the owner of this ticket.' => 'Zusenden einer Mitteilung, wenn ein Kunde eine Nachfrage stellt und ich der Besitzer bin.',
       'Send me a notification if a ticket is moved into a custom queue.' => 'Zusenden einer Mitteilung beim Verschieben eines Tickets in meine bevorzugten Queues.',
       'Send me a notification if a ticket is unlocked by the system.' => 'Zusenden einer Mitteilung, wenn ein Ticket vom System freigegeben (unlocked) wird.',
@@ -183,6 +206,7 @@ sub Data {
       'Show closed tickets.' => 'Geschlossene Tickets anzeigen.',
       'Spelling Dictionary' => 'Rechtschreib-Wrterbuch',
       'Ticket lock timeout notification' => 'Mitteilung bei berschreiten der Sperrzeit',
+      'TicketZoom' => 'Ticket Inhalt',
 
     # Template: AAATicket
       '1 very low' => '1 sehr niedrig',
@@ -241,13 +265,14 @@ sub Data {
       'This is a HTML email. Click here to show it.' => 'Dies ist eine HTML E-Mail. Hier klicken um sie anzusehen.',
       'This message was written in a character set other than your own.' => 'Diese Nachricht wurde in einem Zeichensatz erstellt, der nicht Ihrem eigenen entspricht.',
       'Ticket' => 'Ticket',
+      'Ticket "%s" created!' => 'Ticket "%s" erstellt!',
       'To' => 'An',
       'to open it in a new window.' => 'um sie in einem neuen Fenster angezeigt zu bekommen',
       'unlock' => 'frei',
       'Unlock' => 'Freigeben',
       'very high' => 'sehr hoch',
       'very low' => 'sehr niedrig',
-      'View' => 'Ansicht',
+      'View' => 'Ansehen',
       'webrequest' => 'Webanfrage',
       'Zoom' => 'Inhalt',
 
@@ -261,16 +286,14 @@ sub Data {
       'Wed' => 'Mit',
 
     # Template: AdminAttachmentForm
-      'Add attachment' => 'Anlage hinzufgen',
+      'Add' => 'Hinzufgen',
       'Attachment Management' => 'Anlagen-Verwaltung',
-      'Change attachment settings' => 'Anlage-Einstellungen ndern',
 
     # Template: AdminAutoResponseForm
       'Add auto response' => 'Auto-Antwort hinzufgen',
       'Auto Response From' => 'Auto-Antwort-Absender',
       'Auto Response Management' => 'Auto-Antworten-Verwaltung',
       'Change auto response settings' => 'Auto-Antworten-Einstellungen ndern',
-      'Charset' => 'Zeichensatz',
       'Note' => 'Notiz',
       'Response' => 'Antwort',
       'to get the first 20 character of the subject' => 'Um die ersten 20 Zeichen des Betreffs zu bekommen',
@@ -282,27 +305,34 @@ sub Data {
       'Type' => 'Typ',
       'Useable options' => 'Verfgbare Optionen',
 
-    # Template: AdminCharsetForm
-      'Add charset' => 'Zeichensatz hinzufgen',
-      'Change system charset setting' => 'ndere Zeichensatz',
-      'System Charset Management' => 'Zeichensatz-Verwaltung',
-
     # Template: AdminCustomerUserForm
-      'Add customer user' => 'Hinzufgen eines Kunden-Benutzers',
-      'Change customer user settings' => 'Kunden-Benutzer-Einstellungen ndern',
       'Customer User Management' => 'Kunden-Benutzer-Verwaltung',
-      'Update customer user' => 'Kunden-Benutzer ndern',
       'Customer user will be needed to to login via customer panels.' => 'Kunden-Benutzer werden fr die Kunden-Weboberflche bentigt',
+      'Select source:' => 'Quellen Auswahl',
+      'Source' => 'Quelle',
 
     # Template: AdminCustomerUserGeneric
 
+    # Template: AdminCustomerUserGroupChangeForm
+      'Change %s settings' => 'ndern der %s Einstellungen',
+      'Customer User <-> Group Management' => 'Kundenbenutzer <-> Gruppen Verwaltung',
+      'Full read and write access to the tickets in this group/queue.' => 'Voller schreib und lese Zugriff zu tickets in der Queue/Gruppe.',
+      'If nothing is selected, then there are no permissions in this group (tickets will not be available for the user).' => 'Ist nichts ausgewhlt, dann sind keine Rechte vergeben (diese Tickets sind nicht verfgbar fr diesen Benutzer).',
+      'Permission' => 'Rechte',
+      'Read only access to the ticket in this group/queue.' => 'Nur lese Zugriff fr Tickets in diesen Gruppen/Queues.',
+      'ro' => '',
+      'rw' => '',
+      'Select the user:group permissions.' => 'Auswahl der Benutzer:Gruppen Rechte.',
+
+    # Template: AdminCustomerUserGroupForm
+      'Change user <-> group settings' => 'ndern der Benutzer <-> Gruppe Einstellungen',
+
     # Template: AdminCustomerUserPreferencesGeneric
 
     # Template: AdminEmail
       'Admin-Email' => '',
       'Body' => '',
       'OTRS-Admin Info!' => '',
-      'Permission' => 'Rechte',
       'Recipents' => 'Empfnger',
       'send' => 'Senden',
 
@@ -310,8 +340,6 @@ sub Data {
       'Message sent to' => 'Nachricht gesendet an',
 
     # Template: AdminGroupForm
-      'Add group' => 'Gruppe hinzufgen',
-      'Change group settings' => 'Gruppe ndern',
       'Create new groups to handle access permissions for different groups of agent (e. g. purchasing department, support department, sales department, ...).' => 'Erstellen Sie neue Gruppen, um die Zugriffe fr verschiedene Agenten-Gruppen zu definieren (z.B. Einkaufs-Abteilung, Support-Abteilung, Verkaufs-Abteilung, ...).',
       'Group Management' => 'Gruppen-Verwaltung',
       'It\'s useful for ASP solutions.' => 'Sehr ntzlich fr ASP-Lsungen.',
@@ -322,17 +350,18 @@ sub Data {
 
     # Template: AdminNavigationBar
       'AdminEmail' => '',
-      'AgentFrontend' => 'Agent-Oberflche',
       'Attachment <-> Response' => 'Anlage <-> Antworten',
       'Auto Response <-> Queue' => 'Auto-Antworten <-> Queues',
       'Auto Responses' => 'Auto-Antworten',
-      'Charsets' => 'Zeichenstze',
       'Customer User' => 'Kunden-Benutzer',
+      'Customer User <-> Groups' => 'Kunden-Benutzer <-> Gruppen',
       'Email Addresses' => 'E-Mail-Adressen',
       'Groups' => 'Gruppen',
       'Logout' => 'Abmelden',
       'Misc' => 'Sonstiges',
-      'POP3 Account' => 'POP3-Konto',
+      'Notifications' => 'Nachrichten',
+      'PostMaster Filter' => '',
+      'PostMaster POP3 Account' => 'PostMaster POP3-Konto',
       'Responses' => 'Antworten',
       'Responses <-> Queue' => 'Antworten <-> Queues',
       'Select Box' => '',
@@ -341,10 +370,16 @@ sub Data {
       'System' => '',
       'User <-> Groups' => 'Benutzer <-> Gruppen',
 
+    # Template: AdminNotificationForm
+      'Config options (e. g. &lt;OTRS_CONFIG_HttpType&gt;)' => 'Konfig Optionen (z. B. &lt;OTRS_CONFIG_HttpType&gt;)',
+      'Notification Management' => 'Benachrichtigungs Management',
+      'Notifications are sent to an agent or a customer.' => 'Notifications werden zu Agenten und Kunden gesendet.',
+      'Options of the current customer user data (e. g. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;)' => 'Optionen der Kunden Benutzer Daten (z. B. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;)',
+      'Options of the current user who requested this action (e. g. &lt;OTRS_CURRENT_USERFIRSTNAME&gt;)' => 'Optionen des aktuellen Benutzers der diese Anfrage gerade ausbt (z. B. &lt;OTRS_CURRENT_USERFIRSTNAME&gt;)',
+      'Ticket owner options (e. g. &lt;OTRS_OWNER_USERFIRSTNAME&gt;)' => 'Ticket Besitzer Optionen (z. B. &lt;OTRS_OWNER_USERFIRSTNAME&gt;)',
+
     # Template: AdminPOP3Form
-      'Add POP3 Account' => 'POP3-Konto hinzufgen',
       'All incoming emails with one account will be dispatched in the selected queue!' => 'Einkommende E-Mails von POP3-Konten werden in die ausgewhlte Queue einsortiert!',
-      'Change POP3 Account setting' => 'POP3-Konto ndern',
       'Dispatching' => 'Verteilung',
       'Host' => 'Rechner',
       'If your account is trusted, the x-otrs header (for priority, ...) will be used!' => 'Wird dem Konto vertraut, werden die X-OTRS Header benutzt!',
@@ -352,6 +387,11 @@ sub Data {
       'POP3 Account Management' => 'POP3-Konten-Verwaltung',
       'Trusted' => 'Vertraut',
 
+    # Template: AdminPostMasterFilterForm
+      'Match' => 'Treffer',
+      'PostMasterFilter Management' => '',
+      'Set' => 'Setzen',
+
     # Template: AdminQueueAutoResponseForm
       'Queue <-> Auto Response Management' => 'Queue <-> Auto-Antworten Verwaltung',
 
@@ -360,8 +400,6 @@ sub Data {
     # Template: AdminQueueForm
       '0 = no escalation' => '0 = keine Eskalation',
       '0 = no unlock' => '0 = keine Freigabe',
-      'Add queue' => 'Queue hinzufgen',
-      'Change queue settings' => 'Queue ndern',
       'Customer Move Notify' => 'Kundeninfo Verschieben',
       'Customer Owner Notify' => 'Kundeninfo Besitzer',
       'Customer State Notify' => 'Kundeninfo Status',
@@ -384,7 +422,6 @@ sub Data {
       'Will be the sender address of this queue for email answers.' => 'Absenderadresse fr E-Mails aus dieser Queue.',
 
     # Template: AdminQueueResponsesChangeForm
-      'Change %s settings' => 'ndern der %s Einstellungen',
       'Std. Responses <-> Queue Management' => 'Std. Antworten <-> Queue Verwaltung',
 
     # Template: AdminQueueResponsesForm
@@ -399,14 +436,12 @@ sub Data {
 
     # Template: AdminResponseForm
       'A response is default text to write faster answer (with default text) to customers.' => 'Eine Antwort ist ein vorgegebener Text, um Kunden schneller antworten zu knnen.',
-      'Add response' => 'Antwort hinzufgen',
-      'Change response settings' => 'Antwort ndern',
       'Don\'t forget to add a new response a queue!' => 'Eine neue Antwort muss einer Queue zugewiesen werden!',
+      'Next state' => 'Nchster Status',
       'Response Management' => 'Antworten-Verwaltung',
+      'The current ticket state is' => 'Der aktuelle Ticket-Status ist',
 
     # Template: AdminSalutationForm
-      'Add salutation' => 'Anrede hinzufgen',
-      'Change salutation settings' => 'Anrede ndern',
       'customer realname' => 'Wirklicher Kundenname',
       'for agent firstname' => 'fr Vorname des Agents',
       'for agent lastname' => 'fr Nachname des Agents',
@@ -423,34 +458,32 @@ sub Data {
       'SQL' => '',
 
     # Template: AdminSession
+      'Agent' => '',
       'kill all sessions' => 'Alle Sitzungen lschen',
+      'Overview' => 'bersicht',
+      'Sessions' => 'Sitzung',
+      'Uniq' => '',
 
     # Template: AdminSessionTable
       'kill session' => 'Sitzung lschen',
       'SessionID' => '',
 
     # Template: AdminSignatureForm
-      'Add signature' => 'Signatur hinzufgen',
-      'Change signature settings' => 'ndere Signatur',
       'Signature Management' => 'Signatur-Verwaltung',
 
     # Template: AdminStateForm
-      'Add state' => 'Status hinzufgen',
-      'Change system state setting' => 'ndere Status',
+      'See also' => 'Siehe auch',
       'State Type' => 'Status-Typ',
       'System State Management' => 'Status-Verwaltung',
+      'Take care that you also updated the default states in you Kernel/Config.pm!' => 'Gib acht, dass auch die default Stati im Kernel/Config.pm verndert wurden!',
 
     # Template: AdminSystemAddressForm
-      'Add system address' => 'E-Mail-Adresse hinzufgen',
       'All incoming emails with this "Email" (To:) will be dispatched in the selected queue!' => 'Alle eingehenden E-Mails mit diesem Empfnger (To:) werden in die ausgewhlte Queue einsortiert.',
-      'Change system address setting' => 'ndere E-Mail-Adresse',
       'Email' => 'E-Mail',
       'Realname' => '',
       'System Email Addresses Management' => 'E-Mail-Adressen-Verwaltung',
 
     # Template: AdminUserForm
-      'Add user' => 'Benutzer hinzufgen',
-      'Change user settings' => 'Benutzereinstellungen ndern',
       'Don\'t forget to add a new user to groups!' => 'Ein neuer Benutzer muss einer Gruppe zugewiesen werden!',
       'Firstname' => 'Vorname',
       'Lastname' => 'Nachname',
@@ -458,14 +491,28 @@ sub Data {
       'User will be needed to handle tickets.' => 'Benutzer werden bentigt, um Tickets zu bearbeiten.',
 
     # Template: AdminUserGroupChangeForm
-      'Change  settings' => '',
+      'create' => 'Erstellen',
+      'move_into' => 'Verscheiben in',
+      'owner' => 'Besitzer',
+      'Permissions to change the ticket owner in this group/queue.' => 'Rechte um Ticket Besitzer in Gruppe/Queue zu ndern.',
+      'Permissions to change the ticket priority in this group/queue.' => 'Rechte um Ticket Prioritt in Gruppe/Queue zu ndern.',
+      'Permissions to create tickets in this group/queue.' => 'Rechte um Tickets in Gruppe/Queue zu erstellen.',
+      'Permissions to move tickets into this group/queue.' => 'Rechte um Tickets in Gruppe/Queue zu verschieben.',
+      'priority' => 'Prioritt',
       'User <-> Group Management' => 'Benutzer <-> Gruppe Verwaltung',
 
     # Template: AdminUserGroupForm
-      'Change user <-> group settings' => 'ndern der Benutzer <-> Gruppe Einstellungen',
 
     # Template: AdminUserPreferencesGeneric
 
+    # Template: AgentBook
+      'Address Book' => 'Adressbuch',
+      'Discard all changes and return to the compose screen' => 'Alle nderungen verwerfen und zurck zum Verfassen-Fenster',
+      'Return to the compose screen' => 'Zurck zum Verfassen-Fenster',
+      'Search' => 'Suche',
+      'The message being composed has been closed.  Exiting.' => 'Die erstellte Nachricht wurde geschlossen.',
+      'This window must be called from compose window' => 'Dieses Fenster muss ber das Verfassen-Fenster aufgerufen werden',
+
     # Template: AgentBounce
       'A message should have a To: recipient!' => 'Eine Nachricht sollte einen Empfnger im An: haben!',
       'Bounce ticket' => '',
@@ -478,6 +525,7 @@ sub Data {
 
     # Template: AgentClose
       ' (work units)' => ' (Arbeitseinheiten)',
+      'A message should have a body!' => 'Eine Nachricht sollte einen Body haben!',
       'A message should have a subject!' => 'Eine Nachricht sollte einen Betreff haben!',
       'Close ticket' => 'Ticket schlieen',
       'Close type' => 'Art des Schlieens',
@@ -505,17 +553,22 @@ sub Data {
       'Set customer user and customer id of a ticket' => 'Kunden-Benutzer und Kunden-Nummer des Tickets auswhlen',
 
     # Template: AgentCustomerHistory
+      'All customer tickets.' => 'Alle Kunden Tickets.',
       'Customer history' => 'Kunden-Historie',
 
-    # Template: AgentCustomerHistoryTable
-
     # Template: AgentCustomerMessage
       'Follow up' => '',
-      'Next state' => 'Nchster Status',
 
     # Template: AgentCustomerView
       'Customer Data' => 'Kunden-Daten',
 
+    # Template: AgentEmailNew
+      'All Agents' => 'Alle Agents',
+      'Clear From' => 'Von: lschen',
+      'Compose Email' => 'Email-Erstellen',
+      'Lock Ticket' => 'Ticket Sperren',
+      'new ticket' => 'Neues Ticket',
+
     # Template: AgentForward
       'Article type' => 'Artikeltyp',
       'Date' => 'Datum',
@@ -548,16 +601,19 @@ sub Data {
       'up' => 'aufwrts',
 
     # Template: AgentMailboxTicket
+      '"}' => '',
+      '"}","14' => '',
 
     # Template: AgentMove
       'Move Ticket' => 'Ticket Verschieben',
+      'New Owner' => 'Neuer Besitzer',
       'New Queue' => 'Neue Queue',
-      'New user' => 'Neuer Besitzer',
+      'Previous Owner' => 'Vorheriger Besitzer',
+      'Queue ID' => '',
 
     # Template: AgentNavigationBar
       'Locked tickets' => 'Eigene Tickets',
       'new message' => 'Neue Nachrichten',
-      'PhoneView' => 'Telefon-Ansicht',
       'Preferences' => 'Einstellungen',
       'Utilities' => 'Werkzeuge',
 
@@ -581,9 +637,6 @@ sub Data {
       'Phone call at %s' => 'Anruf am %s',
 
     # Template: AgentPhoneNew
-      'Clear From' => '\'Von:\' lschen',
-      'create' => 'Erstellen',
-      'new ticket' => 'Neues Ticket',
 
     # Template: AgentPlain
       'ArticleID' => '',
@@ -604,16 +657,11 @@ sub Data {
 
     # Template: AgentPriority
       'Change priority of ticket' => 'Prioritt ndern fr Ticket',
-      'New state' => 'Neue Prioritt',
 
     # Template: AgentSpelling
       'Apply these changes' => 'nderungen bernehmen',
-      'Discard all changes and return to the compose screen' => 'Alle nderungen verwerfen und zurck zum Verfassen-Fenster',
-      'Return to the compose screen' => 'Zurck zum Verfassen-Fenster',
       'Spell Checker' => 'Rechtschreibprfung',
       'spelling error(s)' => 'Rechtschreibfehler',
-      'The message being composed has been closed.  Exiting.' => 'Die erstellte Nachricht wurde geschlossen.',
-      'This window must be called from compose window' => 'Dieses Fenster muss ber das Verfassen-Fenster aufgerufen werden',
 
     # Template: AgentStatusView
       'D' => 'Z',
@@ -628,6 +676,10 @@ sub Data {
 
     # Template: AgentStatusViewTableNotAnswerd
 
+    # Template: AgentTicketLink
+      'Link' => 'Verknpfung',
+      'Link to' => 'Verknpfung zu',
+
     # Template: AgentTicketLocked
       'Ticket locked!' => 'Ticket gesperrt!',
       'Ticket unlock!' => 'Ticket freigeben!',
@@ -638,15 +690,27 @@ sub Data {
     # Template: AgentTicketPrintHeader
       'Accounted time' => 'Zugewiesene Zeit',
       'Escalation in' => 'Eskalation in',
-      'printed by' => 'gedruckt von',
 
     # Template: AgentUtilSearch
-      'Article free text' => 'Artikel-Freitext',
-      'Fulltext search (e. g. "Mar*in" or "Baue*" or "martin+hallo")' => 'Volltextsuche (z.B. "Mar*in" oder "Baue*" oder "martin+hallo")',
-      'search' => 'Suche',
-      'search (e. g. 10*5155 or 105658*)' => 'Suche (z.B. "10*5155" oder "105658*")',
-      'Ticket free text' => 'Ticket-Freitext',
+      '(e. g. 10*5155 or 105658*)' => 'z.B. 10*5144 oder 105658*',
+      '(e. g. 234321)' => 'z.B. 234321',
+      '(e. g. U5150)' => 'z.B. U5150',
+      'and' => 'und',
+      'Customer User Login' => 'Kunden-Benutzer-Login',
+      'Delete' => 'Lschen',
+      'Fulltext-Search in Article (e. g. "Mar*in" or "Baue*")' => 'Volltextsuche in Artikel (z.B. "Mar*in" oder "Baue*")',
+      'No time settings.' => 'Keine Zeit-Einstellungen.',
+      'Profile' => 'Profil',
+      'Result Form' => 'Ergebnis-Ansicht',
+      'Save Search-Profile as Template?' => 'Speichere Such-Profil als Vorlage?',
+      'Search-Template' => 'Such-Vorlage',
+      'Select' => 'Auswahl',
+      'Ticket created' => 'Ticket erstellt',
+      'Ticket created between' => 'Ticket erstellt zwischen',
       'Ticket Search' => 'Ticket-Suche',
+      'TicketFreeText' => '',
+      'Times' => 'Zeiten',
+      'Yes, save it with name' => 'Ja, speichere mit Namen',
 
     # Template: AgentUtilSearchByCustomerID
       'Customer history search' => 'Kunden-Historie-Suche',
@@ -654,10 +718,24 @@ sub Data {
       'No * possible!' => 'Kein "*" mglich!',
 
     # Template: AgentUtilSearchNavBar
+      'Change search options' => 'Such-Optionen ndern',
       'Results' => 'Ergebnis',
+      'Search Result' => 'Such-Ergebnis',
       'Total hits' => 'Treffer gesamt',
 
     # Template: AgentUtilSearchResult
+      '"}","15' => '',
+
+    # Template: AgentUtilSearchResultPrint
+
+    # Template: AgentUtilSearchResultPrintTable
+      '"}","30' => '',
+
+    # Template: AgentUtilSearchResultShort
+
+    # Template: AgentUtilSearchResultShortTable
+
+    # Template: AgentUtilSearchResultShortTableNotAnswered
 
     # Template: AgentUtilTicketStatus
       'All closed tickets' => 'Alle geschlossenen Tickets',
@@ -681,13 +759,14 @@ sub Data {
       'Split' => 'Teilen',
 
     # Template: AgentZoomBody
-      'Change queue' => 'Wechsele Queue',
+      'Change queue' => 'Queue wechseln',
 
     # Template: AgentZoomHead
       'Free Fields' => 'Freie Felder',
       'Print' => 'Drucken',
 
     # Template: AgentZoomStatus
+      '"}","18' => '',
 
     # Template: CustomerCreateAccount
       'Create Account' => 'Account erstellen',
@@ -695,6 +774,36 @@ sub Data {
     # Template: CustomerError
       'Traceback' => '',
 
+    # Template: CustomerFAQArticleHistory
+      'Edit' => 'Bearbeiten',
+      'FAQ History' => 'FAQ Historie',
+
+    # Template: CustomerFAQArticlePrint
+      'Category' => 'Kategorie',
+      'Keywords' => 'Schlsselwrter',
+      'Last update' => 'Letzte nderungen',
+      'Problem' => '',
+      'Solution' => 'Lsung',
+      'Symptom' => '',
+
+    # Template: CustomerFAQArticleSystemHistory
+      'FAQ System History' => 'FAQ System Historie',
+
+    # Template: CustomerFAQArticleView
+      'FAQ Article' => 'FAQ Artikel',
+      'Modified' => 'Verndert',
+
+    # Template: CustomerFAQOverview
+      'FAQ Overview' => 'FAQ bersicht',
+
+    # Template: CustomerFAQSearch
+      'FAQ Search' => 'FAQ Suche',
+      'Fulltext' => 'Volltext',
+      'Keyword' => 'Schlsselwort',
+
+    # Template: CustomerFAQSearchResult
+      'FAQ Search Result' => 'FAQ Suche-Ergebnis',
+
     # Template: CustomerFooter
       'Powered by' => '',
 
@@ -717,7 +826,7 @@ sub Data {
 
     # Template: CustomerNavigationBar
       'Create new Ticket' => 'Neues Ticket erstellen',
-      'My Tickets' => 'Meine Tickets',
+      'FAQ' => '',
       'New Ticket' => 'Neues Ticket',
       'Ticket-Overview' => 'Ticket-bersicht',
       'Welcome %s' => 'Willkommen %s',
@@ -729,6 +838,7 @@ sub Data {
     # Template: CustomerPreferencesPassword
 
     # Template: CustomerStatusView
+      'My Tickets' => 'Meine Tickets',
 
     # Template: CustomerStatusViewTable
 
@@ -737,7 +847,41 @@ sub Data {
     # Template: CustomerWarning
 
     # Template: Error
-      'Click here to report a bug!' => 'Klicken Sie hier um einen Fehler zu berichten!',
+      'Click here to report a bug!' => 'Klicken Sie hier, um einen Fehler zu berichten!',
+
+    # Template: FAQArticleDelete
+      'FAQ Delete' => 'FAQ Lschen',
+      'You really want to delete this article?' => 'Artikel wirklich lschen?',
+
+    # Template: FAQArticleForm
+      'Comment (internal)' => 'Kommentar (intern)',
+      'Filename' => 'Dateiname',
+      'Short Description' => 'Kurzbeschreibung',
+
+    # Template: FAQArticleHistory
+
+    # Template: FAQArticlePrint
+
+    # Template: FAQArticleSystemHistory
+
+    # Template: FAQArticleView
+
+    # Template: FAQCategoryForm
+      'FAQ Category' => 'FAQ Kategorie',
+
+    # Template: FAQLanguageForm
+      'FAQ Language' => 'FAQ Sprache',
+
+    # Template: FAQNavigationBar
+
+    # Template: FAQOverview
+
+    # Template: FAQSearch
+
+    # Template: FAQSearchResult
+
+    # Template: FAQStateForm
+      'FAQ State' => 'FAQ Status',
 
     # Template: Footer
       'Top of Page' => 'Seitenanfang',
@@ -778,12 +922,12 @@ sub Data {
       'OTRS DB Name' => '',
       'OTRS DB Password' => 'OTRS DB Passwort',
       'OTRS DB User' => 'OTRS DB Benuter',
-      'your MySQL DB should have a root password! Default is empty!' => 'Deine MySQL DB sollte ein Root Passwort haben! Voreingestellte ist nichts!',
+      'your MySQL DB should have a root password! Default is empty!' => 'Deine MySQL DB sollte ein Root Passwort haben! Voreingestellt ist keines!',
 
     # Template: InstallerSystem
-      '(Checks MX recordes of used email addresses by composing an answer. Don\'t use CheckMXRecord if your OTRS machine is behinde a dial-up line $!)' => '(berprfen des MX Eintrags von benutzen Email Adressen im Verfassen-Fenster. Benutze CheckMXRecord nicht wenn Ihr OTRS hinter einer Whlleitung ist!)',
+      '(Checks MX recordes of used email addresses by composing an answer. Don\'t use CheckMXRecord if your OTRS machine is behinde a dial-up line $!)' => '(berprfen des MX Eintrags von benutzen Email Adressen im Verfassen-Fenster. Benutzen Sie CheckMXRecord nicht, wenn Ihr OTRS hinter einer Whlleitung ist!)',
       '(Email of the system admin)' => '(E-Mail des System Admins)',
-      '(Full qualified domain name of your system)' => '(Foller Domain-Name des Systems)',
+      '(Full qualified domain name of your system)' => '(Voll qualifizierter Domain-Name des Systems)',
       '(Logfile just needed for File-LogModule!)' => '(Logfile nur bentigt fr File-LogModule!)',
       '(The identify of the system. Each ticket number and each http session id starts with this number)' => '(Das Kennzeichnen des Systems. Jede Ticket Nummer und http Sitzung beginnt mit dieser ID)',
       '(Ticket identifier. Some people want toset this to e. g. \'Ticket#\', \'Call#\' or \'MyTicket#\')' => '(Ticket Kennzeichnen. Z.B. \'Ticket#\', \'Call#\' oder \'MyTicket#\')',
@@ -800,6 +944,7 @@ sub Data {
       'SystemID' => '',
       'Ticket Hook' => '',
       'Ticket Number Generator' => 'Ticket Nummer Generator',
+      'Use utf-8 it your database supports it!' => 'Benutze utf-8 wenn Deine Datenbank es untersttzt!',
       'Webfrontend' => 'Web-Oberflche',
 
     # Template: Login
@@ -816,9 +961,11 @@ sub Data {
       'URL' => '',
 
     # Template: PrintHeader
+      'printed by' => 'gedruckt von',
 
     # Template: QueueView
       'All tickets' => 'Alle Tickets',
+      'Page' => 'Seite',
       'Queues' => 'Queues',
       'Tickets available' => 'Tickets verfgbar',
       'Tickets shown' => 'Tickets angezeigt',
@@ -840,63 +987,34 @@ sub Data {
     # Template: Warning
 
     # Misc
-      '(Click here to add a group)' => '(Hier klicken - Gruppe hinzufgen)',
-      '(Click here to add a queue)' => '(Hier klicken - Queue hinzufgen)',
-      '(Click here to add a response)' => '(Hier klicken - Antwort hinzufgen)',
-      '(Click here to add a salutation)' => '(Hier klicken - Anrede hinzufgen)',
-      '(Click here to add a signature)' => '(Hier klicken - Signatur hinzufgen)',
-      '(Click here to add a system email address)' => '(Hier klicken - System-E-Mail-Adresse hinzufgen)',
-      '(Click here to add a customer user)' => '(Hier klicken - Kunden-Benutzer hinzufgen)',
-      '(Click here to add a user)' => '(Hier klicken - Benutzer hinzufgen)',
-      '(Click here to add an auto response)' => '(Hier klicken - Auto-Antwort hinzufgen)',
-      '(Click here to add charset)' => '(Hier klicken - Zeichensatz hinzufgen',
-      '(Click here to add language)' => '(Hier klicken - Sprache hinzufgen)',
-      '(Click here to add state)' => '(Hier klicken - Status hinzufgen)',
-      '(E-Mail of the system admin)' => '(E-Mail des System-Administrator)',
-      'A message should have a From: recipient!' => 'Eine Nachricht sollte einen Absender (Von:) haben!',
-      'Add language' => 'Sprache hinzufgen',
-      'Backend' => '',
+      'Addressbook' => 'Adressbuch',
+      'AgentFrontend' => 'Agent-Oberflche',
+      'Article free text' => 'Artikel-Freitext',
       'BackendMessage' => 'Backend-Nachricht',
       'Bottom of Page' => 'Seitenende',
-      'Change system language setting' => 'ndere Systemsprache',
+      'Charset' => 'Zeichensatz',
+      'Charsets' => 'Zeichenstze',
+      'Closed' => 'Geschlossen',
       'Create' => 'Erstellen',
       'CustomerUser' => 'Kunden-Benutzer',
-      'FAQ' => '',
-      'Fulltext search' => 'Volltext-Suche',
-      'Handle' => '',
-      'In Queue' => '',
       'New ticket via call.' => 'Neues Ticket durch Anruf.',
+      'New user' => 'Neuer Besitzer',
       'Search in' => 'Suche in',
-      'Set customer id of a ticket' => 'Setze eine Kunden# eines Ticket',
       'Show all' => 'Alle anzeigen',
-      'System Language Management' => 'Systemsprache-Verwaltung',
-      'Ticket limit:' => '',
+      'Shown Tickets' => 'Angezeigte Tickets',
+      'System Charset Management' => 'Zeichensatz-Verwaltung',
       'Time till escalation' => 'Zeit bis zur Eskalation',
-      'Update auto response' => 'Auto-Antwort aktualisieren',
-      'Update charset' => 'Zeichensatz aktualisieren',
-      'Update group' => 'Gruppe aktualisieren',
-      'Update language' => 'Sprache aktualisieren',
-      'Update queue' => 'Queue aktualisieren',
-      'Update response' => 'Antworten aktualisieren',
-      'Update salutation' => 'Anrede aktualisieren',
-      'Update signature' => 'Signatur aktualisieren',
-      'Update state' => 'Status aktualisieren',
-      'Update system address' => 'System-E-Mail-Adresse aktualisieren',
-      'Update user' => 'Benutzer aktualisieren',
       'With Priority' => 'Mit Priotitt',
       'With State' => 'Mit Status',
-      'You have to be in the admin group!' => 'Sie mssen dafr in der Admin-Gruppe sein!',
-      'You have to be in the stats group!' => 'Sie mssen dafr in der Statistik-Gruppe sein!',
-      'You need a email address (e. g. customer@example.com) in From:!' => 'Im From-Feld wird eine E-Mail-Adresse (z.B. kunde@beispiel.de) bentigt!',
-      'auto responses set' => 'Auto-Antworten aktiviert',
       'invalid-temporarily' => 'vorbergehend ungltig',
+      'search' => 'Suche',
       'store' => 'Speichern',
       'tickets' => 'Tickets',
       'valid' => 'gltig',
+      'CreateTicket' => 'Ticket Erstellen',
     );
 
     # $$STOP$$
-
     $Self->{Translation} = \%Hash;
 }
 # --
