@@ -2,9 +2,15 @@
 -- initial_insert.sql - provides initial system data
 -- Copyright (C) 2001-2003 Martin Edenhofer <martin+code@otrs.org>
 -- --
--- $Id: initial_insert.sql,v 1.20 2004/02/12 08:18:02 martin Exp $
+-- $Id: initial_insert.sql,v 1.20.2.2 2004/04/02 12:41:10 martin Exp $
 -- 
 -- $Log: initial_insert.sql,v $
+-- Revision 1.20.2.2  2004/04/02 12:41:10  martin
+-- added missing WebRequestCustomer ticket_history_type entry
+--
+-- Revision 1.20.2.1  2004/02/26 23:34:38  martin
+-- some agent notification typos
+--
 -- Revision 1.20  2004/02/12 08:18:02  martin
 -- added customer email snip to escalation and reminder agent notifications
 --
@@ -559,6 +565,10 @@ INSERT INTO ticket_history_type
         (name, valid_id, create_by, create_time, change_by, change_time)
         VALUES
         ('TicketFreeTextUpdate', 1, 1, current_timestamp, 1, current_timestamp);
+INSERT INTO ticket_history_type
+        (name, valid_id, create_by, create_time, change_by, change_time)
+        VALUES
+        ('WebRequestCustomer', 1, 1, current_timestamp, 1, current_timestamp);
 
 -- article_type
 INSERT INTO article_type
@@ -940,7 +950,7 @@ es ist ein neues Ticket in "<OTRS_QUEUE>"!
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_ID>
 
-Dein OTRS Benachrichiguns-Master', current_timestamp, 1, current_timestamp, 1);
+Dein OTRS Benachrichtigungs-Master', current_timestamp, 1, current_timestamp, 1);
 
 INSERT INTO notifications 
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
@@ -956,13 +966,13 @@ Du hast eine Nachfrage bekommen!
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_ID>
 
-Dein OTRS Benachrichiguns-Master', current_timestamp, 1, current_timestamp, 1);
+Dein OTRS Benachrichtigungs-Master', current_timestamp, 1, current_timestamp, 1);
 INSERT INTO notifications 
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
   ('Agent::LockTimeout', 'iso-8859-1', 'de', 'Lock Timeout! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_OWNER_USERFIRSTNAME>,
 
-aufhebung der Sperre auf Dein gesperrtes Ticket [<OTRS_TICKET_NUMBER>].
+Aufhebung der Sperre auf Dein gesperrtes Ticket [<OTRS_TICKET_NUMBER>].
 
 <OTRS_CUSTOMER_FROM> schrieb:
 <snip>
@@ -971,7 +981,7 @@ aufhebung der Sperre auf Dein gesperrtes Ticket [<OTRS_TICKET_NUMBER>].
 
  <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_ID>
 
-Dein OTRS Benachrichiguns-Master', current_timestamp, 1, current_timestamp, 1);
+Dein OTRS Benachrichtigungs-Master', current_timestamp, 1, current_timestamp, 1);
 INSERT INTO notifications 
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
@@ -984,7 +994,7 @@ Kommentar:
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_ID>
 
-Dein OTRS Benachrichiguns-Master', current_timestamp, 1, current_timestamp, 1);
+Dein OTRS Benachrichtigungs-Master', current_timestamp, 1, current_timestamp, 1);
 INSERT INTO notifications 
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
@@ -997,7 +1007,7 @@ Notiz:
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_ID>
 
-Dein OTRS Benachrichiguns-Master', current_timestamp, 1, current_timestamp, 1);
+Dein OTRS Benachrichtigungs-Master', current_timestamp, 1, current_timestamp, 1);
 INSERT INTO notifications 
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
@@ -1007,7 +1017,7 @@ INSERT INTO notifications
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_ID>
 
-Dein OTRS Benachrichiguns-Master', current_timestamp, 1, current_timestamp, 1);
+Dein OTRS Benachrichtigungs-Master', current_timestamp, 1, current_timestamp, 1);
 INSERT INTO notifications 
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
@@ -1020,11 +1030,11 @@ das Ticket "<OTRS_TICKET_NUMBER>" hat die Erinnerungszeit erreicht!
 <OTRS_CUSTOMER_EMAIL[8]>
 <snip>
 
-Bitte um weitere Bearbeutung:
+Bitte um weitere Bearbeitung:
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_ID>
 
-Dein OTRS Benachrichiguns-Master', current_timestamp, 1, current_timestamp, 1);
+Dein OTRS Benachrichtigungs-Master', current_timestamp, 1, current_timestamp, 1);
 INSERT INTO notifications 
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
@@ -1037,9 +1047,9 @@ das Ticket "<OTRS_TICKET_NUMBER>" ist eskaliert!
 <OTRS_CUSTOMER_EMAIL[8]>
 <snip>
 
-MBitte um Bearbeutung:
+MBitte um Bearbeitung:
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_ID>
 
-Dein OTRS Benachrichiguns-Master', current_timestamp, 1, current_timestamp, 1);
+Dein OTRS Benachrichtigungs-Master', current_timestamp, 1, current_timestamp, 1);
 
